@@ -26,6 +26,7 @@ __all__ = (
     "ListSchemasPaginatorName",
     "ListStatementsPaginatorName",
     "ListTablesPaginatorName",
+    "StatementStatusStringType",
     "StatusStringType",
 )
 
@@ -36,4 +37,7 @@ ListDatabasesPaginatorName = Literal["list_databases"]
 ListSchemasPaginatorName = Literal["list_schemas"]
 ListStatementsPaginatorName = Literal["list_statements"]
 ListTablesPaginatorName = Literal["list_tables"]
+StatementStatusStringType = Literal[
+    "ABORTED", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"
+]
 StatusStringType = Literal["ABORTED", "ALL", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"]
